@@ -1,15 +1,39 @@
+# 
+# Copyright (C) 2012  Matthew J Desmarais
+
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+#
+from copy import deepcopy
+
 from astkit.render import SourceCodeRenderer
 
 class LogicalBoolean(object):
     
-    def __init__(self, modulename, node):
+    def __init__(self, modulename, node, parent=None):
         self.modulename = modulename
+        self.node = deepcopy(node)
         self.lineno = node.lineno
         self.source = SourceCodeRenderer.render(node)
         self.pins = len(node.values)
         self.conditions =\
             dict((i, False) for i in range(self.pins + 1))
         self.literals = {}
+        self.parent = parent
+    
+    def is_decision(self):
+        return bool(self.parent)
     
     def number_of_conditions(self):
         return len(self.conditions)
@@ -28,7 +52,7 @@ class LogicalBoolean(object):
         
     def result(self):
         lines = []
-        name = "%s:%s < %s >" % (self.modulename, self.lineno, self.source)
+        name = "%s -> %s:%s < %s >" % (self.__class__.__name__, self.modulename, self.lineno, self.source)
         lines.append("%s" % (name,))
         if self.literals:
             lines.append("")
@@ -39,6 +63,16 @@ class LogicalBoolean(object):
                              " ==> " +\
                              str(self.conditions[condition]))
         return "\n".join(lines)
+    
+    def decision_result(self):
+        lines = []
+        name = "Decision -> %s:%s < %s >" % (self.modulename, self.lineno, self.source)
+        lines.append("%s" % (name,))
+        lines.append("")
+        lines.append("T ==> %r" % self.was_true())
+        lines.append("F ==> %r" % self.was_false())
+        return "\n".join(lines)
+    
 
 class LogicalAnd(LogicalBoolean):
     """ Stores the execution information for a Logical And
@@ -86,7 +120,13 @@ class LogicalAnd(LogicalBoolean):
             return acc
         elif n == (self.pins + 1):
             return "Other"
-        
+    
+    def was_true(self):
+        return self.conditions[0]
+    
+    def was_false(self):
+        return any(self.conditions[n] for n in range(1, self.pins+1))
+    
 class LogicalOr(LogicalBoolean):
     """ Stores the execution information for a Logical Or
         
@@ -131,10 +171,17 @@ class LogicalOr(LogicalBoolean):
         elif n == (self.pins + 1):
             return "Other"
     
+    def was_true(self):
+        return any(self.conditions[n] for n in range(0, self.pins))
+    
+    def was_false(self):
+        return self.conditions[self.pins]
+    
 class BooleanDecision(object):
     
     def __init__(self, modulename, node):
         self.modulename = modulename
+        self.node = deepcopy(node)
         self.lineno = node.lineno
         self.source = SourceCodeRenderer.render(node)
         self.conditions = {True: False,
@@ -158,7 +205,7 @@ class BooleanDecision(object):
     
     def result(self):
         lines = []
-        name = "%s:%s < %s >" % (self.modulename, self.lineno, self.source)
+        name = "Decision -> %s:%s < %s >" % (self.modulename, self.lineno, self.source)
         lines.append("%s" % (name,))
         lines.append("")
         lines.append("T ==> %r" % self.conditions[True])
