@@ -42,6 +42,10 @@ def get_setup():
 
 class ExecutionRecorder(object):
     
+    @classmethod
+    def reset(cls):
+        cls._instance = None
+    
     _instance = None
     @classmethod
     def get(cls):
@@ -56,6 +60,13 @@ class ExecutionRecorder(object):
         self._statements = {}
         self._branches = {}
         self.pragmas = {}
+        self.recording = False
+        
+    def start(self):
+        self.recording = True
+    
+    def stop(self):
+        self.recording = False
     
     def add_source(self, modulename, source):
         self._sources[modulename] = source
@@ -93,17 +104,20 @@ class ExecutionRecorder(object):
         return kall
     
     def record(self, arg, label, *args, **kwargs):
-        self._constructs[label].record(arg, *args, **kwargs)
+        if self.recording:
+            self._constructs[label].record(arg, *args, **kwargs)
         return arg
     
-    def add_BoolOp(self, modulename, node):
+    def add_BoolOp(self, modulename, node, pragmas, parent):
         if isinstance(node.op, ast.And):
             construct_klass = LogicalAnd
         elif isinstance(node.op, ast.Or):
             construct_klass = LogicalOr
         else:
             raise TypeError("Expected a BoolOp node with an op field of ast.And or ast.Or")
-        construct = construct_klass(modulename, node)
+        construct = construct_klass(modulename, node, parent)
+        for pragma in pragmas:
+            construct = pragma(construct)
         
         label = self.next_label()
         self._constructs[label] = construct
@@ -155,7 +169,8 @@ class ExecutionRecorder(object):
         return kall_stmt
     
     def record_statement(self, modulename, lineno):
-        self._statements[modulename][lineno] = True
+        if self.recording:
+            self._statements[modulename][lineno] = True
     
     def add_statement(self, modulename, node):
         lines = self._statements.setdefault(modulename, {})
